@@ -292,6 +292,15 @@ main (int argc, char **argv)
                 gsm_util_init_error (TRUE, "%s", error->message);
         }
 
+        /* From 3.14 GDM sets XDG_CURRENT_DESKTOP. For compatibility with
+         * older versions of GDM,  other display managers, and startx,
+         * set a fallback value if we don't find it set.
+         */
+        if (g_getenv ("XDG_CURRENT_DESKTOP") == NULL) {
+            g_setenv("XDG_CURRENT_DESKTOP", "GNOME", TRUE);
+            gsm_util_setenv ("XDG_CURRENT_DESKTOP", "GNOME");
+        }
+
         /* Make sure we initialize gio in a way that does not autostart any daemon */
         initialize_gio ();
 
@@ -375,13 +384,6 @@ main (int argc, char **argv)
                 exit (1);
         }
 
-        /* From 3.14 GDM sets XDG_CURRENT_DESKTOP. For compatibility with
-         * older versions of GDM,  other display managers, and startx,
-         * set a fallback value if we don't find it set.
-         */
-        if (g_getenv ("XDG_CURRENT_DESKTOP") == NULL)
-            gsm_util_setenv ("XDG_CURRENT_DESKTOP", "GNOME");
-
         /* Push locale variables to dbus-daemon */
         maybe_push_env_var ("LC_TIME");
         maybe_push_env_var ("LC_NUMERIC");
